Table Object
================

.. note:: This is everything you need to use `TableDataExtractor`. The other sections, :ref:`input`, :ref:`output`, :ref:`history`, :ref:`footnotes`, :ref:`algorithms`, :ref:`cell_parser`, and :ref:`exceptions` are for reference only.

.. automodule:: tabledataextractor.table.table
    :members:


